osdp_get_file_tx_status

Function osdp_get_file_tx_status 

pub unsafe extern "C" fn osdp_get_file_tx_status(
    ctx: *const osdp_t,
    pd: c_int,
    size: *mut c_int,
    offset: *mut c_int,
) -> c_int
@brief Query file transfer status if one is in progress. Calling this method when there is no file transfer progressing will return error.

@param ctx OSDP context @param pd PD number in case of CP. This param is ignored in PD mode @param size Total size of the file (as obtained from file_ops->open()) @param offset Offset into the file that has been sent/received (CP/PD) @retval 0 on success. -1 on errors.